@@ -30,20 +30,12 @@ from copy import copy, deepcopy
 from typing import Union  # noqa F401
 
 import numpy as np
-from osgeo import gdal_array
-# custom
+from osgeo import gdal, gdal_array, gdalnumeric
 from shapely.geometry import Polygon
 from shapely.wkt import loads as shply_loads
 from six import PY3
-
 # dill -> imported when dumping GeoArray
 
-try:
-    from osgeo import gdal
-    from osgeo import gdalnumeric
-except ImportError:
-    import gdal
-    import gdalnumeric
 from py_tools_ds.convenience.object_oriented import alias_property
 from py_tools_ds.geo.coord_calc import get_corner_coordinates
 from py_tools_ds.geo.coord_grid import snap_bounds_to_pixGrid
